@@ -308,7 +308,7 @@
  * If <stdatomic.h> is available on this architecture,
  * ISC_PLATFORM_HAVESTDATOMIC will be defined.
  */
-#define ISC_PLATFORM_HAVESTDATOMIC 1
+#undef ISC_PLATFORM_HAVESTDATOMIC
 
 /*
  * Define if gcc ASM extension is available
